@@ -12,6 +12,7 @@
 #' @param avoid \code{NA} (default) or one of: \code{"tolls"}, \code{"highways"}, \code{"ferries"} or \code{"indoor"}
 #' @param region The region code, specified as a ccTLD ("top-level domain") two-character value (e.g. \code{"es"} for Spain) (optional)
 #' @param traffic_model The traffic model, one of: \code{"best_guess"} (the default), \code{"pessimistic"}, \code{"optimistic"}. The \code{traffic_model} parameter is only taken into account when \code{departure_time} is specified!
+#' @param transit_mode Transit preferred mode, one or more of: \code{"bus"}, \code{"subway"}, \code{"train"} or \code{"tram"}
 #' @param key Google APIs key
 #' @param quiet Logical; suppress printing URL for Google Maps API call (e.g. to hide API key)
 #' @return XML document with Google Maps Distance Matrix API response
@@ -35,11 +36,23 @@
 #' )
 #'
 #' # Using 'character' input
-#' locations = c("Haifa", "Tel-Aviv", "Jerusalem", "Beer-Sheva")
+#' locations = c("Tel-Aviv", "Jerusalem", "Beer-Sheva", "Eilat")
 #' doc = mp_matrix(
 #'   origins = locations,
-#'   destinations = locations
+#'   destinations = locations,
+#'   key = key
 #' )
+#' 
+#' Setting transit modes
+#' locations = c("Tel-Aviv", "Beer-Sheva", "Eilat")
+#' doc = mp_matrix(
+#'   origins = locations,
+#'   destinations = locations,
+#'   key = key,
+#'   mode = "transit",
+#'   transit_mode = "train"
+#' )
+#' 
 #' }
 
 mp_matrix = function(
@@ -51,6 +64,7 @@ mp_matrix = function(
   avoid = c(NA, "tolls", "highways", "ferries", "indoor"),
   region = NULL,
   traffic_model = c("best_guess", "pessimistic", "optimistic"),
+  transit_mode = c("bus", "subway", "train", "tram"),
   key,
   quiet = FALSE
   ) {
@@ -59,6 +73,7 @@ mp_matrix = function(
   mode = match.arg(mode)
   avoid = match.arg(avoid)
   traffic_model = match.arg(traffic_model)
+  transit_mode = match.arg(transit_mode, several.ok = TRUE)
   .check_posix_time(arrival_time)
   .check_posix_time(departure_time)
 
@@ -122,6 +137,15 @@ mp_matrix = function(
     )
   }
 
+  # Add 'transit_mode'
+  if(mode == "transit") {
+    url = paste0(
+      url,
+      "&transit_mode=",
+      paste0(transit_mode,collapse = "|")
+    )
+  }
+
   # Add key
   if(!is.null(key)) {
     url = paste0(
@@ -140,4 +164,3 @@ mp_matrix = function(
 
 }
 
-
